@@ -178,11 +178,17 @@ def get_build_mode():
 def normalize_branch_name(branch_name):
     """Normalize branch name by removing debian- if exists"""
     brnorm = branch_name
+    codename = get_distribution_codename()
     if brnorm == "debian":
-        brnorm = "debian-master"
-    # If it's a debian branch, ignore starting "debian-"
-    if brnorm.startswith("debian-"):
-        brnorm = brnorm.replace("debian-", "", 1)
+        return "master"
+    elif brnorm == codename:
+        return "master"
+    elif brnorm == "debian-%s" % codename:
+        return "master"
+    elif brnorm.startswith("debian-%s-" % codename):
+        return brnorm.replace("debian-%s-" % codename, "", 1)
+    elif brnorm.startswith("debian-"):
+        return brnorm.replace("debian-", "", 1)
     return brnorm
 
 
@@ -201,8 +207,15 @@ def version_to_tag(version):
 
 
 def undebianize(branch):
+    codename = get_distribution_codename()
     if branch == "debian":
         return "master"
+    elif branch == codename:
+        return "master"
+    elif branch == "debian-%s" % codename:
+        return "master"
+    elif branch.startswith("debian-%s-" % codename):
+        return branch.replace("debian-%s-" % codename, "", 1)
     elif branch.startswith("debian-"):
         return branch.replace("debian-", "")
     else:
